
### CLI

Command line tools for provisioning servers. A sample of the commands:

1. `start` Starts the Boring Man Wrapper API
2. `stop` Stops Boring Man Wrapper API and all servers running therein
3. `add` Adds a server from a preset. Presets are configurable and defined in `presets.py`
4. `add-custom` Adds a server from a settings file path
5. `remove` Kills a server and frees its resources
6. `status` Displays server information in tabular form
